"""adk-fluent: Fluent builder API for Google ADK."""
# Auto-generated for google-adk 1.25.0

__all__ = [
    "A2aAgentExecutor",
    "A2aAgentExecutorConfig",
    "ActiveStreamingTool",
    "AgentConfig",
    "BaseAgent",
    "BaseAgentConfig",
    "AgentRefConfig",
    "ArgumentConfig",
    "CodeConfig",
    "ContextCacheConfig",
    "Agent",
    "LlmAgentConfig",
    "Loop",
    "LoopAgentConfig",
    "FanOut",
    "ParallelAgentConfig",
    "RemoteA2aAgent",
    "RunConfig",
    "ToolThreadPoolConfig",
    "Pipeline",
    "SequentialAgentConfig",
    "App",
    "EventsCompactionConfig",
    "ResumabilityConfig",
    "BaseArtifactService",
    "FileArtifactService",
    "GcsArtifactService",
    "InMemoryArtifactService",
    "RecordingsPlugin",
    "ReplayPlugin",
    "PerAgentDatabaseSessionService",
    "AgentEngineSandboxCodeExecutor",
    "BaseCodeExecutor",
    "BuiltInCodeExecutor",
    "UnsafeLocalCodeExecutor",
    "VertexAiCodeExecutor",
    "FeatureConfig",
    "AudioCacheConfig",
    "BaseMemoryService",
    "InMemoryMemoryService",
    "VertexAiMemoryBankService",
    "VertexAiRagMemoryService",
    "SimplePromptOptimizerConfig",
    "BasePlanner",
    "BuiltInPlanner",
    "PlanReActPlanner",
    "BasePlugin",
    "BigQueryAgentAnalyticsPlugin",
    "BigQueryLoggerConfig",
    "RetryConfig",
    "ContextFilterPlugin",
    "DebugLoggingPlugin",
    "GlobalInstructionPlugin",
    "LoggingPlugin",
    "MultimodalToolResultsPlugin",
    "ReflectAndRetryToolPlugin",
    "SaveFilesAsArtifactsPlugin",
    "InMemoryRunner",
    "Runner",
    "BaseSessionService",
    "GetSessionConfig",
    "DatabaseSessionService",
    "InMemorySessionService",
    "SqliteSessionService",
    "VertexAiSessionService",
    "ForwardingArtifactService",
    "BaseGoogleCredentialsConfig",
    "AgentSimulatorConfig",
    "InjectionConfig",
    "ToolSimulationConfig",
    "AgentSimulatorPlugin",
    "AgentTool",
    "AgentToolConfig",
    "APIHubToolset",
    "ApplicationIntegrationToolset",
    "IntegrationConnectorTool",
    "BaseAuthenticatedTool",
    "BaseTool",
    "BaseToolset",
    "BigQueryCredentialsConfig",
    "BigQueryToolset",
    "BigQueryToolConfig",
    "BigtableCredentialsConfig",
    "BigtableToolset",
    "ComputerUseTool",
    "ComputerUseToolset",
    "DataAgentToolConfig",
    "DataAgentCredentialsConfig",
    "DataAgentToolset",
    "DiscoveryEngineSearchTool",
    "EnterpriseWebSearchTool",
    "ExampleTool",
    "ExampleToolConfig",
    "FunctionTool",
    "GoogleApiTool",
    "GoogleApiToolset",
    "CalendarToolset",
    "DocsToolset",
    "GmailToolset",
    "SheetsToolset",
    "SlidesToolset",
    "YoutubeToolset",
    "GoogleMapsGroundingTool",
    "GoogleSearchAgentTool",
    "GoogleSearchTool",
    "GoogleTool",
    "LoadArtifactsTool",
    "LoadMcpResourceTool",
    "LoadMemoryTool",
    "LongRunningFunctionTool",
    "MCPTool",
    "McpTool",
    "MCPToolset",
    "McpToolset",
    "McpToolsetConfig",
    "OpenAPIToolset",
    "RestApiTool",
    "PreloadMemoryTool",
    "PubSubToolConfig",
    "PubSubCredentialsConfig",
    "PubSubToolset",
    "BaseRetrievalTool",
    "SetModelResponseTool",
    "LoadSkillResourceTool",
    "LoadSkillTool",
    "SkillToolset",
    "SpannerCredentialsConfig",
    "SpannerToolset",
    "BaseToolConfig",
    "ToolArgsConfig",
    "ToolConfig",
    "ToolboxToolset",
    "TransferToAgentTool",
    "UrlContextTool",
    "VertexAiSearchTool",
    "ArtifactSchema",
    "Consumes",
    "Produces",
    "A",
    "ATransform",
    "BuilderBase",
    "CallbackSchema",
    "configure",
    "reset_config",
    "get_config",
    "C",
    "CTransform",
    "CComposite",
    "CPipe",
    "CFromState",
    "CWindow",
    "CUserOnly",
    "CFromAgents",
    "CExcludeAgents",
    "CTemplate",
    "CSelect",
    "CRecent",
    "CCompact",
    "CDedup",
    "CTruncate",
    "CProject",
    "CBudget",
    "CPriority",
    "CFit",
    "CFresh",
    "CRedact",
    "CSummarize",
    "CRelevant",
    "CExtract",
    "CDistill",
    "CValidate",
    "CNotes",
    "CWriteNotes",
    "CRolling",
    "CFromAgentsWindowed",
    "CUser",
    "CManusCascade",
    "CWhen",
    "CPipelineAware",
    "CSharedThread",
    "SessionStrategy",
    "ExecutionMode",
    "E",
    "EComposite",
    "ECriterion",
    "ECase",
    "EvalSuite",
    "EvalReport",
    "ComparisonReport",
    "EPersona",
    "ADKFluentError",
    "BuilderError",
    "GuardViolation",
    "PredicateError",
    "G",
    "GComposite",
    "GGuard",
    "PIIDetector",
    "PIIFinding",
    "ContentJudge",
    "JudgmentResult",
    "deep_clone_builder",
    "add_agent_tool",
    "run_one_shot",
    "run_one_shot_async",
    "run_stream",
    "run_events",
    "run_inline_test",
    "ChatSession",
    "create_session",
    "run_map",
    "run_map_async",
    "StateKey",
    "Artifact",
    "TransformNode",
    "TapNode",
    "FallbackNode",
    "RaceNode",
    "GateNode",
    "MapOverNode",
    "TimeoutNode",
    "RouteNode",
    "TransferNode",
    "CaptureNode",
    "ArtifactNode",
    "DispatchNode",
    "JoinNode",
    "WatchNode",
    "UINode",
    "ExecutionConfig",
    "CompactionConfig",
    "AgentEvent",
    "ToolCallInfo",
    "ToolResponseInfo",
    "Node",
    "AgentNode",
    "SequenceNode",
    "ParallelNode",
    "LoopNode",
    "FullNode",
    "M",
    "MComposite",
    "MiddlewareSchema",
    "NamespaceSpec",
    "merge_keysets",
    "fingerprint_spec",
    "PredicateSchema",
    "evaluate_predicate",
    "PrimitiveBuilderBase",
    "TimedAgent",
    "BackgroundTask",
    "tap",
    "expect",
    "map_over",
    "gate",
    "race",
    "dispatch",
    "join",
    "notify",
    "watch",
    "P",
    "PTransform",
    "PComposite",
    "PPipe",
    "PRole",
    "PContext",
    "PTask",
    "PConstraint",
    "PFormat",
    "PExample",
    "PSection",
    "PWhen",
    "PFromState",
    "PTemplate",
    "PReorder",
    "POnly",
    "PWithout",
    "PCompress",
    "PAdapt",
    "PScaffolded",
    "PVersioned",
    "PromptSchema",
    "Route",
    "Fallback",
    "DeclarativeField",
    "DeclarativeMetaclass",
    "DeclarativeSchema",
    "Reads",
    "Writes",
    "Param",
    "Confirms",
    "Timeout",
    "AgentDefinition",
    "SkillDefinition",
    "parse_skill_file",
    "parse_topology",
    "SkillRegistry",
    "StateSchema",
    "CapturedBy",
    "Scoped",
    "check_state_schema_contracts",
    "ToolRegistry",
    "SearchToolset",
    "search_aware_after_tool",
    "compress_large_result",
    "ToolSchema",
    "T",
    "TComposite",
    "S",
    "STransform",
    "StateDelta",
    "StateReplacement",
    "A2AServer",
    "AgentRegistry",
    "RemoteAgent",
    "SkillDeclaration",
    "agent",
    "TraceContext",
    "DispatchDirective",
    "LoopDirective",
    "Middleware",
    "TopologyHooks",
    "RetryMiddleware",
    "StructuredLogMiddleware",
    "DispatchLogMiddleware",
    "TopologyLogMiddleware",
    "LatencyMiddleware",
    "CostTracker",
    "A2ARetryMiddleware",
    "A2ACircuitBreakerMiddleware",
    "A2ACircuitOpenError",
    "A2ATimeoutMiddleware",
    "review_loop",
    "map_reduce",
    "cascade",
    "fan_out_merge",
    "chain",
    "conditional",
    "supervised",
    "group_chat",
    "a2a_cascade",
    "a2a_fanout",
    "a2a_delegate",
    "ui_form_agent",
    "ui_dashboard_agent",
    "ComparisonSuite",
    "until",
    "Source",
    "Inbox",
    "StreamRunner",
    "get_execution_mode",
    "UI",
    "UIBinding",
    "UICheck",
    "UIComponent",
    "UISurface",
    "Preset",
    "DefaultRuntime",
    "Runtime",
    "ExecutionResult",
    "SessionHandle",
    "Skill",
    "StreamStats",
    "Backend",
    "final_text",
    "register_backend",
    "get_backend",
    "available_backends",
    "AsyncioBackend",
    "DBOSBackend",
    "DBOSRunnable",
    "DBOSWorkerConfig",
    "generate_app_code",
    "PrefectBackend",
    "PrefectRunnable",
    "PrefectWorkerConfig",
    "generate_flow_code",
    "TemporalBackend",
    "TemporalRunnable",
    "TemporalWorkerConfig",
    "generate_worker_code",
    "create_activities",
    "create_workflow_class",
    "create_worker",
    "CompilationResult",
    "EngineCapabilities",
    "compile",
    "run_passes",
    "fuse_transforms",
    "validate_contracts",
    "annotate_checkpoints",
    "ModelProvider",
    "StateStore",
    "ToolRuntime",
    "ArtifactStore",
    "Message",
    "ToolDef",
    "GenerateConfig",
    "GenerateResult",
    "Chunk",
    "ComputeConfig",
    "InMemoryStateStore",
    "InMemoryArtifactStore",
    "LocalToolRuntime",
    "check_contracts",
    "infer_data_flow",
    "DataFlowSuggestion",
    "mock_backend",
    "MockBackend",
    "AgentHarness",
    "HarnessResponse",
    "diagnose",
    "format_diagnosis",
    "Diagnosis",
    "AgentSummary",
    "KeyFlow",
    "ContractIssue",
    "DataFlowContract",
    "check_data_flow_contract",
]

_LAZY_IMPORTS: dict[str, tuple[str, str]] = {
    "A2aAgentExecutor": (".executor", "A2aAgentExecutor"),
    "A2aAgentExecutorConfig": (".config", "A2aAgentExecutorConfig"),
    "ActiveStreamingTool": (".tool", "ActiveStreamingTool"),
    "AgentConfig": (".config", "AgentConfig"),
    "BaseAgent": (".agent", "BaseAgent"),
    "BaseAgentConfig": (".config", "BaseAgentConfig"),
    "AgentRefConfig": (".config", "AgentRefConfig"),
    "ArgumentConfig": (".config", "ArgumentConfig"),
    "CodeConfig": (".config", "CodeConfig"),
    "ContextCacheConfig": (".config", "ContextCacheConfig"),
    "Agent": (".agent", "Agent"),
    "LlmAgentConfig": (".config", "LlmAgentConfig"),
    "Loop": (".workflow", "Loop"),
    "LoopAgentConfig": (".config", "LoopAgentConfig"),
    "FanOut": (".workflow", "FanOut"),
    "ParallelAgentConfig": (".config", "ParallelAgentConfig"),
    "RemoteA2aAgent": (".agent", "RemoteA2aAgent"),
    "RunConfig": (".config", "RunConfig"),
    "ToolThreadPoolConfig": (".config", "ToolThreadPoolConfig"),
    "Pipeline": (".workflow", "Pipeline"),
    "SequentialAgentConfig": (".config", "SequentialAgentConfig"),
    "App": (".runtime", "App"),
    "EventsCompactionConfig": (".config", "EventsCompactionConfig"),
    "ResumabilityConfig": (".config", "ResumabilityConfig"),
    "BaseArtifactService": (".service", "BaseArtifactService"),
    "FileArtifactService": (".service", "FileArtifactService"),
    "GcsArtifactService": (".service", "GcsArtifactService"),
    "InMemoryArtifactService": (".service", "InMemoryArtifactService"),
    "RecordingsPlugin": (".plugin", "RecordingsPlugin"),
    "ReplayPlugin": (".plugin", "ReplayPlugin"),
    "PerAgentDatabaseSessionService": (".service", "PerAgentDatabaseSessionService"),
    "AgentEngineSandboxCodeExecutor": (".executor", "AgentEngineSandboxCodeExecutor"),
    "BaseCodeExecutor": (".executor", "BaseCodeExecutor"),
    "BuiltInCodeExecutor": (".executor", "BuiltInCodeExecutor"),
    "UnsafeLocalCodeExecutor": (".executor", "UnsafeLocalCodeExecutor"),
    "VertexAiCodeExecutor": (".executor", "VertexAiCodeExecutor"),
    "FeatureConfig": (".config", "FeatureConfig"),
    "AudioCacheConfig": (".config", "AudioCacheConfig"),
    "BaseMemoryService": (".service", "BaseMemoryService"),
    "InMemoryMemoryService": (".service", "InMemoryMemoryService"),
    "VertexAiMemoryBankService": (".service", "VertexAiMemoryBankService"),
    "VertexAiRagMemoryService": (".service", "VertexAiRagMemoryService"),
    "SimplePromptOptimizerConfig": (".config", "SimplePromptOptimizerConfig"),
    "BasePlanner": (".planner", "BasePlanner"),
    "BuiltInPlanner": (".planner", "BuiltInPlanner"),
    "PlanReActPlanner": (".planner", "PlanReActPlanner"),
    "BasePlugin": (".plugin", "BasePlugin"),
    "BigQueryAgentAnalyticsPlugin": (".plugin", "BigQueryAgentAnalyticsPlugin"),
    "BigQueryLoggerConfig": (".config", "BigQueryLoggerConfig"),
    "RetryConfig": (".config", "RetryConfig"),
    "ContextFilterPlugin": (".plugin", "ContextFilterPlugin"),
    "DebugLoggingPlugin": (".plugin", "DebugLoggingPlugin"),
    "GlobalInstructionPlugin": (".plugin", "GlobalInstructionPlugin"),
    "LoggingPlugin": (".plugin", "LoggingPlugin"),
    "MultimodalToolResultsPlugin": (".plugin", "MultimodalToolResultsPlugin"),
    "ReflectAndRetryToolPlugin": (".plugin", "ReflectAndRetryToolPlugin"),
    "SaveFilesAsArtifactsPlugin": (".plugin", "SaveFilesAsArtifactsPlugin"),
    "InMemoryRunner": (".runtime", "InMemoryRunner"),
    "Runner": (".runtime", "Runner"),
    "BaseSessionService": (".service", "BaseSessionService"),
    "GetSessionConfig": (".config", "GetSessionConfig"),
    "DatabaseSessionService": (".service", "DatabaseSessionService"),
    "InMemorySessionService": (".service", "InMemorySessionService"),
    "SqliteSessionService": (".service", "SqliteSessionService"),
    "VertexAiSessionService": (".service", "VertexAiSessionService"),
    "ForwardingArtifactService": (".service", "ForwardingArtifactService"),
    "BaseGoogleCredentialsConfig": (".config", "BaseGoogleCredentialsConfig"),
    "AgentSimulatorConfig": (".config", "AgentSimulatorConfig"),
    "InjectionConfig": (".config", "InjectionConfig"),
    "ToolSimulationConfig": (".config", "ToolSimulationConfig"),
    "AgentSimulatorPlugin": (".plugin", "AgentSimulatorPlugin"),
    "AgentTool": (".tool", "AgentTool"),
    "AgentToolConfig": (".config", "AgentToolConfig"),
    "APIHubToolset": (".tool", "APIHubToolset"),
    "ApplicationIntegrationToolset": (".tool", "ApplicationIntegrationToolset"),
    "IntegrationConnectorTool": (".tool", "IntegrationConnectorTool"),
    "BaseAuthenticatedTool": (".tool", "BaseAuthenticatedTool"),
    "BaseTool": (".tool", "BaseTool"),
    "BaseToolset": (".tool", "BaseToolset"),
    "BigQueryCredentialsConfig": (".config", "BigQueryCredentialsConfig"),
    "BigQueryToolset": (".tool", "BigQueryToolset"),
    "BigQueryToolConfig": (".config", "BigQueryToolConfig"),
    "BigtableCredentialsConfig": (".config", "BigtableCredentialsConfig"),
    "BigtableToolset": (".tool", "BigtableToolset"),
    "ComputerUseTool": (".tool", "ComputerUseTool"),
    "ComputerUseToolset": (".tool", "ComputerUseToolset"),
    "DataAgentToolConfig": (".config", "DataAgentToolConfig"),
    "DataAgentCredentialsConfig": (".config", "DataAgentCredentialsConfig"),
    "DataAgentToolset": (".tool", "DataAgentToolset"),
    "DiscoveryEngineSearchTool": (".tool", "DiscoveryEngineSearchTool"),
    "EnterpriseWebSearchTool": (".tool", "EnterpriseWebSearchTool"),
    "ExampleTool": (".tool", "ExampleTool"),
    "ExampleToolConfig": (".config", "ExampleToolConfig"),
    "FunctionTool": (".tool", "FunctionTool"),
    "GoogleApiTool": (".tool", "GoogleApiTool"),
    "GoogleApiToolset": (".tool", "GoogleApiToolset"),
    "CalendarToolset": (".tool", "CalendarToolset"),
    "DocsToolset": (".tool", "DocsToolset"),
    "GmailToolset": (".tool", "GmailToolset"),
    "SheetsToolset": (".tool", "SheetsToolset"),
    "SlidesToolset": (".tool", "SlidesToolset"),
    "YoutubeToolset": (".tool", "YoutubeToolset"),
    "GoogleMapsGroundingTool": (".tool", "GoogleMapsGroundingTool"),
    "GoogleSearchAgentTool": (".tool", "GoogleSearchAgentTool"),
    "GoogleSearchTool": (".tool", "GoogleSearchTool"),
    "GoogleTool": (".tool", "GoogleTool"),
    "LoadArtifactsTool": (".tool", "LoadArtifactsTool"),
    "LoadMcpResourceTool": (".tool", "LoadMcpResourceTool"),
    "LoadMemoryTool": (".tool", "LoadMemoryTool"),
    "LongRunningFunctionTool": (".tool", "LongRunningFunctionTool"),
    "MCPTool": (".tool", "MCPTool"),
    "McpTool": (".tool", "McpTool"),
    "MCPToolset": (".tool", "MCPToolset"),
    "McpToolset": (".tool", "McpToolset"),
    "McpToolsetConfig": (".config", "McpToolsetConfig"),
    "OpenAPIToolset": (".tool", "OpenAPIToolset"),
    "RestApiTool": (".tool", "RestApiTool"),
    "PreloadMemoryTool": (".tool", "PreloadMemoryTool"),
    "PubSubToolConfig": (".config", "PubSubToolConfig"),
    "PubSubCredentialsConfig": (".config", "PubSubCredentialsConfig"),
    "PubSubToolset": (".tool", "PubSubToolset"),
    "BaseRetrievalTool": (".tool", "BaseRetrievalTool"),
    "SetModelResponseTool": (".tool", "SetModelResponseTool"),
    "LoadSkillResourceTool": (".tool", "LoadSkillResourceTool"),
    "LoadSkillTool": (".tool", "LoadSkillTool"),
    "SkillToolset": (".tool", "SkillToolset"),
    "SpannerCredentialsConfig": (".config", "SpannerCredentialsConfig"),
    "SpannerToolset": (".tool", "SpannerToolset"),
    "BaseToolConfig": (".config", "BaseToolConfig"),
    "ToolArgsConfig": (".config", "ToolArgsConfig"),
    "ToolConfig": (".config", "ToolConfig"),
    "ToolboxToolset": (".tool", "ToolboxToolset"),
    "TransferToAgentTool": (".tool", "TransferToAgentTool"),
    "UrlContextTool": (".tool", "UrlContextTool"),
    "VertexAiSearchTool": (".tool", "VertexAiSearchTool"),
    "ArtifactSchema": ("._artifact_schema", "ArtifactSchema"),
    "Consumes": ("._artifact_schema", "Consumes"),
    "Produces": ("._artifact_schema", "Produces"),
    "A": ("._artifacts", "A"),
    "ATransform": ("._artifacts", "ATransform"),
    "BuilderBase": ("._base", "BuilderBase"),
    "CallbackSchema": ("._callback_schema", "CallbackSchema"),
    "configure": ("._config_global", "configure"),
    "reset_config": ("._config_global", "reset_config"),
    "get_config": ("._config_global", "get_config"),
    "C": ("._context", "C"),
    "CTransform": ("._context", "CTransform"),
    "CComposite": ("._context", "CComposite"),
    "CPipe": ("._context", "CPipe"),
    "CFromState": ("._context", "CFromState"),
    "CWindow": ("._context", "CWindow"),
    "CUserOnly": ("._context", "CUserOnly"),
    "CFromAgents": ("._context", "CFromAgents"),
    "CExcludeAgents": ("._context", "CExcludeAgents"),
    "CTemplate": ("._context", "CTemplate"),
    "CSelect": ("._context", "CSelect"),
    "CRecent": ("._context", "CRecent"),
    "CCompact": ("._context", "CCompact"),
    "CDedup": ("._context", "CDedup"),
    "CTruncate": ("._context", "CTruncate"),
    "CProject": ("._context", "CProject"),
    "CBudget": ("._context", "CBudget"),
    "CPriority": ("._context", "CPriority"),
    "CFit": ("._context", "CFit"),
    "CFresh": ("._context", "CFresh"),
    "CRedact": ("._context", "CRedact"),
    "CSummarize": ("._context", "CSummarize"),
    "CRelevant": ("._context", "CRelevant"),
    "CExtract": ("._context", "CExtract"),
    "CDistill": ("._context", "CDistill"),
    "CValidate": ("._context", "CValidate"),
    "CNotes": ("._context", "CNotes"),
    "CWriteNotes": ("._context", "CWriteNotes"),
    "CRolling": ("._context", "CRolling"),
    "CFromAgentsWindowed": ("._context", "CFromAgentsWindowed"),
    "CUser": ("._context", "CUser"),
    "CManusCascade": ("._context", "CManusCascade"),
    "CWhen": ("._context", "CWhen"),
    "CPipelineAware": ("._context", "CPipelineAware"),
    "CSharedThread": ("._context", "CSharedThread"),
    "SessionStrategy": ("._enums", "SessionStrategy"),
    "ExecutionMode": ("._enums", "ExecutionMode"),
    "E": ("._eval", "E"),
    "EComposite": ("._eval", "EComposite"),
    "ECriterion": ("._eval", "ECriterion"),
    "ECase": ("._eval", "ECase"),
    "EvalSuite": ("._eval", "EvalSuite"),
    "EvalReport": ("._eval", "EvalReport"),
    "ComparisonReport": ("._eval", "ComparisonReport"),
    "EPersona": ("._eval", "EPersona"),
    "ADKFluentError": ("._exceptions", "ADKFluentError"),
    "BuilderError": ("._exceptions", "BuilderError"),
    "GuardViolation": ("._exceptions", "GuardViolation"),
    "PredicateError": ("._exceptions", "PredicateError"),
    "G": ("._guards", "G"),
    "GComposite": ("._guards", "GComposite"),
    "GGuard": ("._guards", "GGuard"),
    "PIIDetector": ("._guards", "PIIDetector"),
    "PIIFinding": ("._guards", "PIIFinding"),
    "ContentJudge": ("._guards", "ContentJudge"),
    "JudgmentResult": ("._guards", "JudgmentResult"),
    "deep_clone_builder": ("._helpers", "deep_clone_builder"),
    "add_agent_tool": ("._helpers", "add_agent_tool"),
    "run_one_shot": ("._helpers", "run_one_shot"),
    "run_one_shot_async": ("._helpers", "run_one_shot_async"),
    "run_stream": ("._helpers", "run_stream"),
    "run_events": ("._helpers", "run_events"),
    "run_inline_test": ("._helpers", "run_inline_test"),
    "ChatSession": ("._helpers", "ChatSession"),
    "create_session": ("._helpers", "create_session"),
    "run_map": ("._helpers", "run_map"),
    "run_map_async": ("._helpers", "run_map_async"),
    "StateKey": ("._helpers", "StateKey"),
    "Artifact": ("._helpers", "Artifact"),
    "TransformNode": ("._ir", "TransformNode"),
    "TapNode": ("._ir", "TapNode"),
    "FallbackNode": ("._ir", "FallbackNode"),
    "RaceNode": ("._ir", "RaceNode"),
    "GateNode": ("._ir", "GateNode"),
    "MapOverNode": ("._ir", "MapOverNode"),
    "TimeoutNode": ("._ir", "TimeoutNode"),
    "RouteNode": ("._ir", "RouteNode"),
    "TransferNode": ("._ir", "TransferNode"),
    "CaptureNode": ("._ir", "CaptureNode"),
    "ArtifactNode": ("._ir", "ArtifactNode"),
    "DispatchNode": ("._ir", "DispatchNode"),
    "JoinNode": ("._ir", "JoinNode"),
    "WatchNode": ("._ir", "WatchNode"),
    "UINode": ("._ir", "UINode"),
    "ExecutionConfig": ("._ir", "ExecutionConfig"),
    "CompactionConfig": ("._ir", "CompactionConfig"),
    "AgentEvent": ("._ir", "AgentEvent"),
    "ToolCallInfo": ("._ir", "ToolCallInfo"),
    "ToolResponseInfo": ("._ir", "ToolResponseInfo"),
    "Node": ("._ir", "Node"),
    "AgentNode": ("._ir_generated", "AgentNode"),
    "SequenceNode": ("._ir_generated", "SequenceNode"),
    "ParallelNode": ("._ir_generated", "ParallelNode"),
    "LoopNode": ("._ir_generated", "LoopNode"),
    "FullNode": ("._ir_generated", "FullNode"),
    "M": ("._middleware", "M"),
    "MComposite": ("._middleware", "MComposite"),
    "MiddlewareSchema": ("._middleware_schema", "MiddlewareSchema"),
    "NamespaceSpec": ("._namespace_protocol", "NamespaceSpec"),
    "merge_keysets": ("._namespace_protocol", "merge_keysets"),
    "fingerprint_spec": ("._namespace_protocol", "fingerprint_spec"),
    "PredicateSchema": ("._predicate_schema", "PredicateSchema"),
    "evaluate_predicate": ("._predicate_utils", "evaluate_predicate"),
    "PrimitiveBuilderBase": ("._primitive_builders", "PrimitiveBuilderBase"),
    "TimedAgent": ("._primitive_builders", "TimedAgent"),
    "BackgroundTask": ("._primitive_builders", "BackgroundTask"),
    "tap": ("._primitive_builders", "tap"),
    "expect": ("._primitive_builders", "expect"),
    "map_over": ("._primitive_builders", "map_over"),
    "gate": ("._primitive_builders", "gate"),
    "race": ("._primitive_builders", "race"),
    "dispatch": ("._primitive_builders", "dispatch"),
    "join": ("._primitive_builders", "join"),
    "notify": ("._primitive_builders", "notify"),
    "watch": ("._primitive_builders", "watch"),
    "P": ("._prompt", "P"),
    "PTransform": ("._prompt", "PTransform"),
    "PComposite": ("._prompt", "PComposite"),
    "PPipe": ("._prompt", "PPipe"),
    "PRole": ("._prompt", "PRole"),
    "PContext": ("._prompt", "PContext"),
    "PTask": ("._prompt", "PTask"),
    "PConstraint": ("._prompt", "PConstraint"),
    "PFormat": ("._prompt", "PFormat"),
    "PExample": ("._prompt", "PExample"),
    "PSection": ("._prompt", "PSection"),
    "PWhen": ("._prompt", "PWhen"),
    "PFromState": ("._prompt", "PFromState"),
    "PTemplate": ("._prompt", "PTemplate"),
    "PReorder": ("._prompt", "PReorder"),
    "POnly": ("._prompt", "POnly"),
    "PWithout": ("._prompt", "PWithout"),
    "PCompress": ("._prompt", "PCompress"),
    "PAdapt": ("._prompt", "PAdapt"),
    "PScaffolded": ("._prompt", "PScaffolded"),
    "PVersioned": ("._prompt", "PVersioned"),
    "PromptSchema": ("._prompt_schema", "PromptSchema"),
    "Route": ("._routing", "Route"),
    "Fallback": ("._routing", "Fallback"),
    "DeclarativeField": ("._schema_base", "DeclarativeField"),
    "DeclarativeMetaclass": ("._schema_base", "DeclarativeMetaclass"),
    "DeclarativeSchema": ("._schema_base", "DeclarativeSchema"),
    "Reads": ("._schema_base", "Reads"),
    "Writes": ("._schema_base", "Writes"),
    "Param": ("._schema_base", "Param"),
    "Confirms": ("._schema_base", "Confirms"),
    "Timeout": ("._schema_base", "Timeout"),
    "AgentDefinition": ("._skill_parser", "AgentDefinition"),
    "SkillDefinition": ("._skill_parser", "SkillDefinition"),
    "parse_skill_file": ("._skill_parser", "parse_skill_file"),
    "parse_topology": ("._skill_parser", "parse_topology"),
    "SkillRegistry": ("._skill_registry", "SkillRegistry"),
    "StateSchema": ("._state_schema", "StateSchema"),
    "CapturedBy": ("._state_schema", "CapturedBy"),
    "Scoped": ("._state_schema", "Scoped"),
    "check_state_schema_contracts": ("._state_schema", "check_state_schema_contracts"),
    "ToolRegistry": ("._tool_registry", "ToolRegistry"),
    "SearchToolset": ("._tool_registry", "SearchToolset"),
    "search_aware_after_tool": ("._tool_registry", "search_aware_after_tool"),
    "compress_large_result": ("._tool_registry", "compress_large_result"),
    "ToolSchema": ("._tool_schema", "ToolSchema"),
    "T": ("._tools", "T"),
    "TComposite": ("._tools", "TComposite"),
    "S": ("._transforms", "S"),
    "STransform": ("._transforms", "STransform"),
    "StateDelta": ("._transforms", "StateDelta"),
    "StateReplacement": ("._transforms", "StateReplacement"),
    "A2AServer": (".a2a", "A2AServer"),
    "AgentRegistry": (".a2a", "AgentRegistry"),
    "RemoteAgent": (".a2a", "RemoteAgent"),
    "SkillDeclaration": (".a2a", "SkillDeclaration"),
    "agent": (".decorators", "agent"),
    "TraceContext": (".middleware", "TraceContext"),
    "DispatchDirective": (".middleware", "DispatchDirective"),
    "LoopDirective": (".middleware", "LoopDirective"),
    "Middleware": (".middleware", "Middleware"),
    "TopologyHooks": (".middleware", "TopologyHooks"),
    "RetryMiddleware": (".middleware", "RetryMiddleware"),
    "StructuredLogMiddleware": (".middleware", "StructuredLogMiddleware"),
    "DispatchLogMiddleware": (".middleware", "DispatchLogMiddleware"),
    "TopologyLogMiddleware": (".middleware", "TopologyLogMiddleware"),
    "LatencyMiddleware": (".middleware", "LatencyMiddleware"),
    "CostTracker": (".middleware", "CostTracker"),
    "A2ARetryMiddleware": (".middleware", "A2ARetryMiddleware"),
    "A2ACircuitBreakerMiddleware": (".middleware", "A2ACircuitBreakerMiddleware"),
    "A2ACircuitOpenError": (".middleware", "A2ACircuitOpenError"),
    "A2ATimeoutMiddleware": (".middleware", "A2ATimeoutMiddleware"),
    "review_loop": (".patterns", "review_loop"),
    "map_reduce": (".patterns", "map_reduce"),
    "cascade": (".patterns", "cascade"),
    "fan_out_merge": (".patterns", "fan_out_merge"),
    "chain": (".patterns", "chain"),
    "conditional": (".patterns", "conditional"),
    "supervised": (".patterns", "supervised"),
    "group_chat": (".patterns", "group_chat"),
    "a2a_cascade": (".patterns", "a2a_cascade"),
    "a2a_fanout": (".patterns", "a2a_fanout"),
    "a2a_delegate": (".patterns", "a2a_delegate"),
    "ui_form_agent": (".patterns", "ui_form_agent"),
    "ui_dashboard_agent": (".patterns", "ui_dashboard_agent"),
    "ComparisonSuite": (".prelude", "ComparisonSuite"),
    "until": (".prelude", "until"),
    "Source": (".prelude", "Source"),
    "Inbox": (".prelude", "Inbox"),
    "StreamRunner": (".prelude", "StreamRunner"),
    "get_execution_mode": (".prelude", "get_execution_mode"),
    "UI": (".prelude", "UI"),
    "UIBinding": (".prelude", "UIBinding"),
    "UICheck": (".prelude", "UICheck"),
    "UIComponent": (".prelude", "UIComponent"),
    "UISurface": (".prelude", "UISurface"),
    "Preset": (".presets", "Preset"),
    "DefaultRuntime": (".runtime_default", "DefaultRuntime"),
    "Runtime": (".runtime_protocol", "Runtime"),
    "ExecutionResult": (".runtime_protocol", "ExecutionResult"),
    "SessionHandle": (".runtime_protocol", "SessionHandle"),
    "Skill": (".skill", "Skill"),
    "StreamStats": (".stream", "StreamStats"),
    "Backend": (".backends", "Backend"),
    "final_text": (".backends", "final_text"),
    "register_backend": (".backends", "register_backend"),
    "get_backend": (".backends", "get_backend"),
    "available_backends": (".backends", "available_backends"),
    "AsyncioBackend": (".backends.asyncio_backend", "AsyncioBackend"),
    "DBOSBackend": (".backends.dbos_backend", "DBOSBackend"),
    "DBOSRunnable": (".backends.dbos_backend", "DBOSRunnable"),
    "DBOSWorkerConfig": (".backends.dbos_worker", "DBOSWorkerConfig"),
    "generate_app_code": (".backends.dbos_worker", "generate_app_code"),
    "PrefectBackend": (".backends.prefect_backend", "PrefectBackend"),
    "PrefectRunnable": (".backends.prefect_backend", "PrefectRunnable"),
    "PrefectWorkerConfig": (".backends.prefect_worker", "PrefectWorkerConfig"),
    "generate_flow_code": (".backends.prefect_worker", "generate_flow_code"),
    "TemporalBackend": (".backends.temporal", "TemporalBackend"),
    "TemporalRunnable": (".backends.temporal", "TemporalRunnable"),
    "TemporalWorkerConfig": (".backends.temporal_worker", "TemporalWorkerConfig"),
    "generate_worker_code": (".backends.temporal_worker", "generate_worker_code"),
    "create_activities": (".backends.temporal_worker", "create_activities"),
    "create_workflow_class": (".backends.temporal_worker", "create_workflow_class"),
    "create_worker": (".backends.temporal_worker", "create_worker"),
    "CompilationResult": (".compile", "CompilationResult"),
    "EngineCapabilities": (".compile", "EngineCapabilities"),
    "compile": (".compile", "compile"),
    "run_passes": (".compile.passes", "run_passes"),
    "fuse_transforms": (".compile.passes", "fuse_transforms"),
    "validate_contracts": (".compile.passes", "validate_contracts"),
    "annotate_checkpoints": (".compile.passes", "annotate_checkpoints"),
    "ModelProvider": (".compute", "ModelProvider"),
    "StateStore": (".compute", "StateStore"),
    "ToolRuntime": (".compute", "ToolRuntime"),
    "ArtifactStore": (".compute", "ArtifactStore"),
    "Message": (".compute", "Message"),
    "ToolDef": (".compute", "ToolDef"),
    "GenerateConfig": (".compute", "GenerateConfig"),
    "GenerateResult": (".compute", "GenerateResult"),
    "Chunk": (".compute", "Chunk"),
    "ComputeConfig": (".compute", "ComputeConfig"),
    "InMemoryStateStore": (".compute", "InMemoryStateStore"),
    "InMemoryArtifactStore": (".compute", "InMemoryArtifactStore"),
    "LocalToolRuntime": (".compute.memory", "LocalToolRuntime"),
    "check_contracts": (".testing", "check_contracts"),
    "infer_data_flow": (".testing", "infer_data_flow"),
    "DataFlowSuggestion": (".testing", "DataFlowSuggestion"),
    "mock_backend": (".testing", "mock_backend"),
    "MockBackend": (".testing", "MockBackend"),
    "AgentHarness": (".testing", "AgentHarness"),
    "HarnessResponse": (".testing", "HarnessResponse"),
    "diagnose": (".testing", "diagnose"),
    "format_diagnosis": (".testing", "format_diagnosis"),
    "Diagnosis": (".testing", "Diagnosis"),
    "AgentSummary": (".testing", "AgentSummary"),
    "KeyFlow": (".testing", "KeyFlow"),
    "ContractIssue": (".testing", "ContractIssue"),
    "DataFlowContract": (".testing", "DataFlowContract"),
    "check_data_flow_contract": (".testing", "check_data_flow_contract"),
}

# Names that conflict with subpackage names — need special resolution
_SUBPACKAGE_EXPORTS: dict[str, tuple[str, str]] = {
    "compile": (".compile", "compile"),
}


def _fix_subpackage_shadows():
    """Fix attributes shadowed by subpackage auto-imports.

    Python's import system auto-sets parent.child = <module>
    when importing parent.child. This can shadow our lazy
    function/class exports when a subpackage name matches
    an exported name (e.g. 'compile' is both a subpackage
    and an exported function).
    """
    import types

    _spx = globals().get("_SUBPACKAGE_EXPORTS", {})
    for _name, (_mod, _attr) in _spx.items():
        _val = globals().get(_name)
        if isinstance(_val, types.ModuleType):
            globals()[_name] = getattr(_val, _attr)


def __getattr__(name: str):
    if name in _LAZY_IMPORTS:
        import importlib

        _mod, _attr = _LAZY_IMPORTS[name]
        module = importlib.import_module(_mod, __name__)
        value = getattr(module, _attr)
        globals()[name] = value
        # Importing a submodule may auto-set subpackage names
        # in our namespace — fix any that got shadowed.
        _fix_subpackage_shadows()
        return value
    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")


def __dir__():
    return __all__
